
      subroutine blends
c******************************************************************************
c     This program does abundance derivations from blended spectral features;
c     only one element will have its abundance derived per run.
c******************************************************************************

      implicit real*8 (a-h,o-z)
      include 'Chars.com'
      include 'Atmos.com'
      include 'Linex.com'
      include 'Factor.com'
      include 'Mol.com'
      include 'Pstuff.com'
      integer sm_device
      character choice
 

c*****examine the parameter file
      call params


c*****set up the output files
      nwrite = 20     
      array = 'Give the filename for standard output: '
      nchars = 39
      call infile ('output ',nwrite,'formatted  ',0,nchars,4)
      ndump = 21               
      array = 'Give the filename for abundance summaries: '
      nchars = 43
      call infile ('output ',ndump,'formatted  ',0,nchars,6)


c*****set up the model atmosphere                                        
      filemodel = 30
      array = 'Give the filename for the model atmosphere: '
      nchars = 44
      call infile ('input  ',filemodel,'formatted  ',0,nchars,10)
      call inmodel


c*****initialize some variables
      isynth = 1
      isorun = 1
      iatom = int(cogatom)
      pec(iatom) = 1
      numpecatom = 1
      pecabund(iatom,1) = 0.
      if (numiso .gt. 0) call out (26)


c*****set up the line list
      filelines = 31
      array = 'Give the filename for the line list: '
      nchars = 37
      call infile ('input  ',filelines,'formatted  ',0,nchars,12)
      call inlines (1)
      call eqlib
      call nearly


c*****define the set of lines responsible for a blended feature
      ipr(5) = -1
      mode = 4
30    call linlimit
      lim1 = lim1line
      lim2 = lim2line


c*****make sure that the element whose abundance is to be fit has
c     a representative line of the blend
      do j=lim1,lim2
         if (atom1(j) .lt. 100.) then
            if (iatom .eq. int(atom1(j))) go to 10
         else
            call sunder (atom1(j),ia,ib)
            if (iatom.eq.ia .or. iatom.eq.ib) go to 10
         endif
      enddo
      do j=lim1,lim2
         abunout(j) = 999.99
      enddo
      write (nwrite,*) 'WARNING: NO ELEMENT LINE TO VARY IN BLEND'
      go to 29
 

c*****do the syntheses, forcing each abundance to predict the
c     feature equivalent width
10    ncurve = 1
      start = wave1(lim1) - delwave
      stop = wave1(lim2) + delwave
      delta = wave1(lim2) - wave1(lim1) + delwave
      oldstart = start
      oldstop = stop
      oldstep = step
      olddelta = delta
      rwlgobs = dlog10(width(lim1)/wave1(lim1))
      gf1(ncurve) = 1.
15    call synspec
      call total
      error = (w(ncurve)-width(lim1))/width(lim1)
      ratio = width(lim1)/w(ncurve)
      ncurve = ncurve + 1


c*****here we go for another iteration
      if (dabs(error) .ge. 0.0075) then
         rwlcomp = dlog10(w(ncurve-1)/wave1(lim1))
         if     (rwlcomp.lt.-5.2 .and. rwlgobs.lt.-5.2) then 
            ratio = ratio
         elseif (rwlcomp.ge.-5.2 .and. rwlgobs.ge.-5.2) then 
            ratio = ratio**2.0
         else   
            ratio = ratio**1.5
         endif
         gf1(ncurve) = gf1(ncurve-1)*ratio
         do j=lim1,lim2
            if (atom1(j) .gt. 100.) then
               call sunder (atom1(j),ia,ib)
               if (ia.eq.iatom .or. ib.eq.iatom) then
                  do i=1,ntau                                
                     kapnu0(j,i) = kapnu0(j,i)*ratio            
                  enddo
               endif
            elseif (int(atom1(j)) .eq. iatom) then
               do i=1,ntau                                
                  kapnu0(j,i) = kapnu0(j,i)*ratio            
               enddo
            endif
         enddo
         go to 15
      else


c*****here we do the final calculation when the predicted and observed are close
         gf1(ncurve) = gf1(ncurve-1)*ratio
         do j=lim1,lim2
            if (atom1(j) .gt. 100.) then
               call sunder (atom1(j),ia,ib)
               if (ia.eq.iatom .or. ib.eq.iatom) then
                  do i=1,ntau                                
                     kapnu0(j,i) = kapnu0(j,i)*ratio            
                  enddo
               endif
            elseif (int(atom1(j)) .eq. iatom) then
               do i=1,ntau                                
                  kapnu0(j,i) = kapnu0(j,i)*ratio            
               enddo
            endif
         enddo
         call synspec
         call total
         widout(lim1) = w(ncurve)
         diff = dlog10(gf1(ncurve))
         abunout(lim1) = dlog10(xabund(iatom)) + 12.0 + diff
      endif
      call out (24)


c*****assign the abundance to the strongest line of the blend that
c     contains cogatom; put 999.99's as the abudnances of all but 
c     this line; go back for another blended feature
      if (lim2 .gt. lim1) then
         abunblend = abunout(lim1)
         widblend = widout(lim1)
         strongest = 0.
         linstrongest = 0
         do j=lim1,lim2
            abunout(j) = 999.99
         enddo
         do j=lim1,lim2
            if (atom1(j) .lt. 100.) then
               if (dint(atom1(j)) .eq. cogatom) then
                  if (kapnu0(j,jtau5) .gt. strongest) then
                     strongest = kapnu0(j,jtau5)
                     linstrongest = j
                  endif
               endif
            else
               call sunder (atom1(j),ia,ib)
               if (dble(ia).eq.cogatom .or. dble(ib).eq.cogatom) then
                  if (kapnu0(j,jtau5) .gt. strongest) then
                     strongest = kapnu0(j,jtau5)
                     linstrongest = j
                  endif
               endif
            endif
         enddo
         abunout(linstrongest) = abunblend
         widout(linstrongest) = widblend
      endif
29    lim1line = lim2line + 1
      if (lim1line .le. nlines) go to 30


c*****do abundance statistics; print out a summary of the abundances 
      lim1obs = 1
      lim2obs = nlines
      call stats
      rewind ndump

c
c curt mode AMcW 2/2000
c
      if (curt) then
         call out (29)
      else
         call out (25)
      endif


c*****here a plot may be made on the terminal (and paper) if there
c     are enough lines
      if (kount .ge. ipr(7)) then
55       choice = 'y'
         if (sm_device(smterm) .lt. 0) then
            write (nwrite,1006) smterm
1006        format ('DEVICE OPENING ERROR FOR:',a54)
            stop
         endif
         call sm_graphics
         call sm_erase
         call linplot (choice)
         call sm_gflush
         call sm_alpha
         array = '   MAKE A HARDCOPY OF THIS PLOT ([n]/h/f/r)? '
         ikount = min0(nlines+11,maxline)
         nchars = 45
         call getasci (nchars,ikount)
         choice = chinfo(1:1)
         if (choice.eq.'n' .or. nchars.le.0) then
            go to 60
         elseif (choice .eq. 'h') then
            if (sm_device('postport') .lt. 0) then
               write (nwrite,1008)
1008           format ('DEVICE OPENING ERROR FOR: postport')
               stop
            endif
            call sm_graphics
            call sm_erase
            call linplot (choice)
            call sm_gflush
            call sm_alpha
            call sm_hardcopy
         elseif (choice .eq. 'r') then
            go to 55
         elseif (choice .eq. 'f') then
            array =
     .        'Give the file name for the POSTSRIPT plot image: '
            nchars = 49
            ikount = min0(nlines+12,maxline)
            call getasci (nchars,ikount)
            write (array,1005) chinfo(1:nchars)
1005        format ('postfile ',a71)
            if (sm_device(array(1:nchars+9)) .lt. 0) then
               write (nwrite,1007) array(1:nchars+9)
1007           format ('FILE OPENING ERROR FOR:',a56)
               stop
            endif
            call sm_graphics
            call sm_erase
            call linplot (choice)
            call sm_gflush
            call sm_alpha
            call sm_hardcopy
         endif
      endif


c*****now the option will be to redo the molecular equilibrium and redo
c     the last species, at the user's option.
60    if (neq .ne. 0) then
         do n=1,neq
            if (iatom .eq. iorder(n)) then
               write (array,1004)
1004           format ('SPECIES USES MOLECULAR EQUILIBRIUM!',
     .               '  REDO WITH NEW ABUNDANCE ([y]/n)? ')
               ikount = min0(nlines+11,maxline)
               nchars = 70
35             call getasci (nchars,ikount)
               choice = chinfo(1:1)
               if (choice.eq.'y' .or. nchars.le.0) then
                  xabund(iatom) = 10.**(average-12.)
                  call eqlib
                  call nearly
                  lim1line = 0
                  lim2line = 0
                  rewind ndump
                  go to 30
               elseif (choice .eq. 'n') then
                  go to 36
               else
                  go to 35
               endif
            endif
         enddo
      else
      endif
 

c*****exit the program
36    call finish

      end                                                                








