
      subroutine nearly                                                  
c******************************************************************************
c     This routine calculates the quantity 'kapnu0' for each line and       
c     each tau; this is the line opacity at line center.  When kapnu0 is 
c     multiplied by the voigt function, one gets the line opacity at an 
c     arbitrary wavelength.  The damping parameter 'a' and the doppler   
c     factor 'dopp' are also computed                                    
c******************************************************************************

      implicit real*8 (a-h,o-z)
      include 'Atmos.com'
      include 'Quants.com'
      include 'Linex.com'
      include 'Mol.com'
      include 'Dummy.com'
      dimension xnum(75)
      equivalence (xnum,dummy1)


c*****do the whole routine for each line (1:nlines)
      do j=1,nlines                                                  


c*****set up some parameters
         ich = idint(charge(j) + 0.1)                    
         iatom = atom1(j)                                                   
         factoriso = 1.0d0
    
                  
c*****calculate the doppler factors
         do i=1,ntau                                                     
            dopp(j,i) = dsqrt(1.6631d8*t(i)/amass(j)+vturb(i)**2)               
         enddo


c*****calculate lower state atomic number densities for atoms.  Here,
c     q21 is the ion/neutral ratio, etc., and q is the ratio of the total
c     to the species of interest.  Do the Saha equation first, then
c     the Boltzmann equation
         if (iatom .ge. 100) go to 5                                         
         do i=1,ntau                                                     
            q21 = 4.825d15*u(iatom,2,i)/(u(iatom,1,i)*ne(i))*
     .            t(i)**1.5*dexp(-1.1605d4*chi(j,1)/t(i)) 
            q32 = 4.825d15*u(iatom,3,i)/(u(iatom,2,i)*ne(i))*
     .            t(i)**1.5*dexp(-1.1605d4*chi(j,2)/t(i)) 
            q43 = 4.825d15*u(iatom,4,i)/(u(iatom,3,i)*ne(i))*
     .            t(i)**1.5*dexp(-1.1605d4*chi(j,3)/t(i)) 
            if     (ich .eq. 1) then
               q = 1.0 + q21 + q32*q21 + q43*q32*q21
            elseif (ich .eq. 2) then
               q = 1.0/q21 + 1.0 + q32 + q43*q32
            elseif (ich .eq. 3) then
               q = 1.0/(q21*q32) + 1.0/q32 + 1.0 + q43
            endif
            if (neq .ne. 0) then
               do n=1,neq                                                      
                  if (iatom .eq. iorder(n)) then
                     xnum(i) = xamol(n,i)
                     if     (ich .eq. 1) then
                        q = 1.0
                     elseif (ich .eq. 2) then
                        q = 1.0/q21
                     endif
                     go to 35
                  endif
               enddo
            endif
            xnum(i) = xabund(iatom)*nhtot(i)
35          xnum(i) = xnum(i)/q*dexp(-1.1605d4*e(j,1)/t(i))/
     .             u(iatom,ich,i)   
         enddo
         go to 101                                                          


c*****calculate lower state molecular number densities and line opacities   
c     at line centers                                                       
5        am = chi(j,2)                                                      
         call sunder(atom1(j),iaa,ibb)                                        
         do n=1,neq                                                      
            if(iorder(n) .eq. iaa) ia = n                                       
            if(iorder(n) .eq. ibb) ib = n                                       
         enddo
         do i=1,ntau                                                     
            theta = 5040.0/t(i)                                                
            psipri = 1.38054d-16*t(i)*10.0**(chi(j,1)*theta-13.670)*
     .               theta**2.5/(am**1.5*u(iaa,1,i)*u(ibb,1,i)) 
            xnum(i) = dexp(-1.1605d4*e(j,1)/t(i))*psipri*
     .                xamol(ia,i)*xamol(ib,i)
         enddo


c*****calculate the line opacities at line centers
101      if (atom1(j)-float(iatom) .ge. 0.0) then
            do i=1,numiso
               if (atom1(j) .eq. isotope(i)) then
                  factoriso = isoabund(i,isorun)
               endif
            enddo
         endif
         do i=1,ntau
            kapnu0(j,i) = 2.65386d-2*xnum(i)*gf(j)*wave1(j)*1.0d-8/
     .                 dopp(j,i)*(1.0-dexp(-1.43879d8/
     .                 (wave1(j)*t(i))))/factoriso
c    .                 (wave1(j)*t(i))))/dfloat(factoriso)  replaced original AMcW 1/200
         enddo
         strength(j) = kapnu0(j,jtau5)/factoriso
c        strength(j) = kapnu0(j,jtau5)/dfloat(factoriso)    replaced original AMcW 1/200


c*****calculate the line broadening parameter; call a separate routine 
c     for special cases where the damping parameters are accurately known
         if (itru .eq. 1 .and. (atom1(j).eq.20.1 .or. 
     .       atom1(j).eq.20.0 .or. atom1(j).eq.11.0)) then
            ifind = -1
            call trudamp (j,ifind)
         else
            ifind = 0
         endif
         if (ifind .eq. 0) then
            if (ipr(3) .gt. 1) write (nwrite,1001) j, wave1(j)
1001        format(//' LINE BROADENING PARAMETERS FOR LINE', i4,
     .             ' AT WAVELENGTH',f8.2/
     .             '  i',4x,'natural',6x,'Stark',4x,'VdWaals',
     .             6x,'total',5x,'a(j,i)')
            do i=1,ntau                                                    
               v1 = dsqrt(2.1175d8*t(i)*(1.0/amass(j)+1.008))                   
               gammar = 2.223d15/wave1(j)**2
               excdiff = chi(j,idint(charge(j)+0.001)) - e(j,2)
               if (excdiff .gt. 0.0 .and. atom1(j).lt.100.) then
                  effn2 = 13.6*charge(j)**2/excdiff
               else
                  effn2 = 25.
               endif
               gammas = 1.0e-8*ne(i)*effn2**2.5
               gammav = 17.0*c6(j)**0.4*v1**0.6*nhneutral(i) 
               gammatot = gammar + gammas + gammav
               a(j,i) = gammatot*wave1(j)*1.0d-8/(12.56636*dopp(j,i)) 
               if (ipr(3) .gt. 1) write (nwrite,1002) i,gammar,
     .                            gammas,gammav,gammatot,a(j,i)
1002           format (i3,1p5e11.3)
            enddo
         endif
      enddo

c*****exit the routine normally
      call out (3)
      return                                                             

      end                                                                


