      subroutine params
c******************************************************************************
c     This subroutine reads in the commands from the parameter file
c******************************************************************************

      implicit real*8 (a-h,o-z)
      include 'Chars.com'
      include 'Atmos.com'
      include 'Linex.com'
      include 'Factor.com'
      include 'Pstuff.com'
      include 'Strong.com'
      include 'Mol.com'
      character keyword*10
      character arrayz*80

c  initialize some variables:
c  terminal type
      smterm = ' '
c  atmosphere data [1], molecular equilibrium [2], line data [3], 
c  flux/intensity [4], synthesis/single line computations [5], 
c  line formation [6], plotting [7], damping [8], and
c  observed spectrum file type [9] flags 
      ipr(1) = 1
      ipr(2) = 0
      ipr(3) = 1
      ipr(4) = 0
      ipr(5) = 0
      ipr(6) = 0
      ipr(7) = 0
      ipr(8) = 0
      ipr(9) = 0
      iunits = 0
      itru = 1
      iscale = 0
      nlines = 0
      iraf = 0
      do i=1,100
         pec(i) = 0
      enddo
 
c   if fudge is less than or equal to 0 then it does not scale it...make it
c   -1.0 just to be sure we dont have floating poing problems with 0.0
      fudge = -1.0

c  set curt mode to false as default
c
      curt = .false.

c  elements with special abundance data
      neq = 0
      numpecatom = 0
      numatomsyn = 0
      numiso = 0
      numisosyn = 0
c  spectrum run parameters
      start = 0.
      stop = 0.
      step = 0.
      delta = 0.
      cogatom = 0.
c  line limit parameters
      ncurve = 0
      lim1line = 0
      lim2line = 0
      lim1obs = 0
      lim2obs = 0
      lim1 = 0
      lim2 = 0

c  look for the key word, always in the first 10 columns of a line
c  then act on that keyword
5     write (array,1007)
1007  format (79(' '))
      read (nparam,1001,end=100) arrayz
1001  format (a80)

      i=index(arrayz,' ')
      keyword = arrayz(1:i-1)
      array = arrayz(i:)

c  keyword 'atmosphere' controls the output of atmosphere quantities
c           0 = do not print out the atmosphere
c           1 = print out the standard things about an atmsophere
c           2 = print standard things and additional stuff like continuous
c                    opacities, etc.
      if     (keyword .eq. 'atmosphere') then
         read (array,*) ipr(1)
1003     format (10x,i5)

c  keyword 'molecules ' controls the molecular equilibrium calculations
c           0 = do not do molecular equilibrium
c           1 = do molecular equilibrium but do not print results
c           2 = do molecular equilibrium and print results
      elseif (keyword .eq. 'molecules') then
         read (array,*) ipr(2)

c  keyword 'lines     ' controls the output of line data
c           0 = print out nothing about the input lines
c           1 = print out standard information about the input line list
c           2 = gory line data print (usually for diagnostic purposes)
      elseif (keyword .eq. 'lines') then
         read (array,*) ipr(3)
         iopr(3) = ipr(3)

c  keyword 'pscale    ' allows you to set all of the plotting 
c     parameters if you know them in advance
c     0 = user supplied in plotting routine (default)
c     1 = given in following lines as follows 
c
c     xlow xhi ylo yhi
c     vshift lamshift obsadd obsmult
c     smooth-type smooth-FWHM
      elseif (keyword .eq. 'pscale') then
         read (array,*) iscale
         read (nparam,*) xlo,xhi,ylo,yhi
         read (nparam,*) vmult,xadd,yadd,ymult
         read (nparam,*) smtype,half
c
c keyword 'curt       ' gives curt output   AMcW 1/2000
c
      elseif (keyword .eq. 'curt') then
         curt = .true.


c keyword 'trudamp     '  should moog use the detailed line damping for
c                         those transitions that have information stored in
c                         subroutine trudamp? (Default is *yes*)
      elseif (keyword .eq. 'trudamp') then
         read (array,*) itru


c keyword 'units      ' controls the units in which moog 
c          outputs the final spectrum
c            0 = angs
c            1 = microns
c            2 = 1/cm
      elseif (keyword .eq. 'units') then
         read (array,*) iunits


c keyword 'iraf       ' allows the user to output a raw spectrum in 
c          a form suitable for IRAF's rtext input command
c            0 = don't do this, make output the normal way.
c            1 = make an IRAF-compatible output
      elseif (keyword .eq. 'iraf') then
         read (array,*) iraf


c  keyword 'flux/int  ' choses integrated flux or central intensity
c           0 = integrated flux calculations
c           1 = central intensity calculations
      elseif (keyword .eq. 'flux/int') then
         read (array,*) ipr(4)
 1013   format(8x,i30)

c  keyword 'damping   ' controls the output of line data
c           0 = use the Unsold approximation, except multiply possibly
c                 by a factor read in for an individual line
c           1 = use the Unsold approximation multiplied by 6.3
c           2 = use the Unsold approximation multiplied by the
c                 factor recommended by the Blackwell group
      elseif (keyword .eq. 'damping') then
         read (array,*) ipr(8)

c  keyword 'obspectrum' controls the file type of the observed spectrum
c           0 = no observed spectrum is to be input
c           1 = read a true FITS file
c           2 = (not implemented yet)
c           3 = (not implemented yet)
c           4 = (not implemented yet)
c           5 = read a special MONGO style (wavelength, flux pair) file
      elseif (keyword .eq. 'obspectrum') then
         read (array,*) ipr(9)

c  keyword 'terminal  ' gives the SUPERMONGO terminal type
c           name = the terminal type name that SUPERMONGO recognizes
c                  (see the SUPERMONGO manual for a list)
      elseif (keyword .eq. 'terminal') then
         read (array,*) smterm

c  keyword 'plot      ' decides whether or not to make a plot of results
c           0 = do not make a plot
c           For syntheses: 1 = plot only synthetic spectra
c                          2 = plot synthetic and observed spectra
c           For line analyses: # = the minimum number of lines of a 
c                                  species necessary to trigger a plot
      elseif (keyword .eq. 'plot') then
         read (array,*) ipr(7)

c  keyword 'abundances' gives the changes to be applied to the abundances
c           # = the number of different syntheses to run
c               (the next line gives the different abundance factors
c               to use)
      elseif (keyword .eq. 'abundances') then
         read (array,*) numpecatom,numatomsyn
1005     format (10x,i5,i5)
         do l=1,numpecatom
            read (nparam,*) j,(pecabund(j,k),k=1,numatomsyn)
1019        format(i10,8f8.0)
            pec(j) = 1
         end do

c keyword 'isotopes   ' gives the isotopes used in the line list and their
c                       abundance relative to the parent spiecies
      elseif (keyword .eq. 'isotopes') then
         read (array,*) numiso,numisosyn
         do  j=1,numiso
         read (nparam,*) isotope(j),(isoabund(j,k),k=1,numisosyn)
1012     format(f10.4,8f8.0)
         end do


c  keyword 'synlimits ' gives the wavelength parameters for syntheses
c                        start and stop are beginning and ending
c                        wavelengths, step is the step size in the
c                        syntheses, and delta is the wavelength range
c                        to either side of a synthesis point to consider
c                        for line opacity calculations
      elseif (keyword .eq. 'synlimits') then
         read (nparam,*) start, stop, step, delta

c  keyword 'blenlimits' gives the parameters for blended line abundance
c                        matches.  delwave is the wavelength offset 
c                        to the blue of first and to the red of the 
c                        last line in the blend to extend the syntheses; 
c                        step is the wavelength step size in the 
c                        computations; cogatom is the name of the
c                        element whose abundance should be varied
c                        to achieve an EW match with observations.
      elseif (keyword .eq. 'blenlimits') then
         read (nparam,*) delwave, step, cogatom

c  keyword 'coglimits ' gives the log(W/lambda) limits for curves-of-growth
c                       rwlow and rwhigh are the beginning
c                       and ending points of the log(red.width) values,
c                       rwstep is the step in log(red.width),
c                       cogatom is the declaration of which element
c                       will have its abundance varied (necessary only
c                       for spectrum synthesis curves-of-growth,
c                       and wavestep is a forced (if desired) step size
c                       in wavelength along the line (this applies to
c                       single line computations only
      elseif (keyword .eq. 'coglimits') then
         read (nparam,*) rwlow, rwhigh, rwstep, wavestep, cogatom

c  keyword 'limits    ' old limits format...tell the user to change the
c                       keyword and quit.

      elseif (keyword .eq. 'limits') then
         write(*,*) 'Warning: keyword changed to synlimits or coglimits'
         write(*,*) 'for Syntesis and COG calculations.'
         write(*,*) 
         write(*,*) 'Formats:'
         write(*,*) 'synlimits <start> <stop> <step> <delta>'
         write(*,*) 'coglimits <rwlow> <rwhigh> <rwstep> <cogatom> ',
     .     '<wavestep>'
         stop


c   keyword of strong for lines which are to be considered for all of the 
c   synthesis

      elseif (keyword .eq. 'strong') then
         read (array,*) nstrong
     

c  keyword word of opacit which takes the continuus opacity and scales it
c  with the form of kaplam(i)= kaplam(i)*((factor*10000)/t(i))
c  in Opacit.f after it calulates the normal kaplam
c  if value is <= 0 then it does not do it

      elseif (keyword .eq. 'opacit') then
         read (array,*) fudge
     
      

c  any other keyword causes great grudge
      else
         write (*,1006) keyword
1006     format ('LOOK OUT!  This option is unknown to MOOG: ',
     .          a10)

      endif

c  loop back to get another parameter
      go to 5

c  if no terminal type is given, ask for it

100   if (smterm .eq. ' ') then
         array = 'GIVE THE SUPERMONGO TERMINAL TYPE NAME: '
         nchar = 40
         call getasci (nchar,12)
         smterm = chinfo(1:nchar)
         ivstat = ivcleof(12,1)
      endif

c  at the end of the parameter file, return after converting all working
c  wavlength units to Angstroms
      oldstart = start
      oldstop = stop
      oldstep = step
      olddelta = delta
      if (iunits .eq. 2) then
         stop = 1.d8/oldstart
         start = 1.d8/oldstop
      elseif (iunits .eq. 1) then
         stop = 1.d4*oldstop
         start = 1.d4*oldstart
         step = 1.d4*oldstep
         delta = 1.d4*olddelta
      endif
      return

      end






